@@ -1,5 +1,5 @@
 from .exception import PipelineError, PipelineOutputError, PipelineMessageError
-from .message import Message, DescribeMessage, serialize_message, deserialize_message
+from .message import Message, Command, deserialize_message
 from .tap import DestinationTap, SourceTap, TapKind
 from .worker import (
     ProducerSettings,
@@ -8,8 +8,10 @@ from .worker import (
     Processor,
     SplitterSettings,
     Splitter,
+    CommandActions,
 )
 from .manager import Pipeline
+from .monitor import Monitor
 from .helpers import Settings
 
 
@@ -27,9 +29,10 @@ __all__ = [
     "Processor",
     "SplitterSettings",
     "Splitter",
+    "CommandActions",
     "Message",
-    "DescribeMessage",
-    "serialize_message",
+    "Command",
     "deserialize_message",
     "Pipeline",
+    "Monitor",
 ]
