@@ -3,6 +3,7 @@ import csv
 import logging
 import sys
 import gzip
+import json
 from abc import ABC, abstractmethod
 from logging import Logger
 from enum import Enum
@@ -12,7 +13,7 @@ from pydantic import BaseModel, Field
 
 from .exception import PipelineMessageError
 from .helpers import Settings
-from .message import Message
+from .message import MessageBase, Message, deserialize_message
 from .importor import import_class
 
 
@@ -44,12 +45,12 @@ class SourceTap(ABC):
         self.logger = logger
 
     @abstractmethod
-    def read(self) -> Iterator[Message]:
-        """ receive message. """
+    def read(self) -> Iterator[MessageBase]:
+        """receive message."""
         raise NotImplementedError()
 
     def rewind(self) -> None:
-        """ rewind to earliest message. """
+        """rewind to earliest message."""
         raise NotImplementedError("rewind is not implemented")
 
     @classmethod
@@ -72,11 +73,11 @@ class SourceTap(ABC):
             return classes_or_strings
 
     def close(self) -> None:
-        """ implementation needed when subclassing """
+        """implementation needed when subclassing"""
         pass
 
     def acknowledge(self) -> None:
-        """ implementation needed when subclassing """
+        """implementation needed when subclassing"""
         pass
 
 
@@ -98,8 +99,8 @@ class DestinationTap(ABC):
         self.logger = logger
 
     @abstractmethod
-    def write(self, message: Message) -> int:
-        """ send message. """
+    def write(self, message: MessageBase) -> int:
+        """send message."""
         raise NotImplementedError()
 
     @classmethod
@@ -119,7 +120,7 @@ class DestinationTap(ABC):
             return classes_or_strings
 
     def close(self) -> None:
-        """ implementation needed when subclassing """
+        """implementation needed when subclassing"""
         pass
 
 
@@ -146,9 +147,9 @@ class MemorySource(SourceTap):
         super().__init__(settings, logger)
         self.data = settings.data
 
-    def read(self) -> Iterator[Message]:
+    def read(self) -> Iterator[MessageBase]:
         for i in self.data:
-            if isinstance(i, Message):
+            if isinstance(i, MessageBase):
                 yield i
             elif isinstance(i, dict):
                 yield Message(content=i)
@@ -182,9 +183,9 @@ class MemoryDestination(DestinationTap):
         self, settings: MemoryDestinationSettings, logger: Logger = pipelineLogger
     ) -> None:
         super().__init__(settings=settings, logger=logger)
-        self.results: List[Message] = []
+        self.results: List[MessageBase] = []
 
-    def write(self, message: Message) -> int:
+    def write(self, message: MessageBase) -> int:
         self.results.append(message)
         return 0
 
@@ -193,6 +194,7 @@ class FileSourceSettings(SourceSettings):
     filename: str = Field(
         None, title="input filename, use '-' for stdin", required=True
     )
+    content_only: bool = Field(False, title="input contains only content for messages")
 
 
 class FileSource(SourceTap):
@@ -229,14 +231,23 @@ class FileSource(SourceTap):
     def __repr__(self) -> str:
         return 'FileSource("{}")'.format(self.filename)
 
-    def read(self) -> Iterator[Message]:
-        for line in self.infile:
-            yield Message.deserialize(line)
+    def read(self) -> Iterator[MessageBase]:
+        if self.settings.content_only:
+            for line in self.infile:
+                content = json.loads(line)
+                if content.get("id"):
+                    yield Message(content=content, id=content.get("id"))
+                else:
+                    yield Message(content=content)
+        else:
+            for line in self.infile:
+                yield deserialize_message(line)
 
 
 class FileDestinationSettings(DestinationSettings):
     filename: str = Field(None, title="output filename", required=True)
     overwrite: bool = Field(False, title="overwrite output file if exists")
+    content_only: bool = Field(False, title="input contains only content for messages")
 
 
 class FileDestination(DestinationTap):
@@ -271,8 +282,11 @@ class FileDestination(DestinationTap):
     def __repr__(self) -> str:
         return 'FileDestination("{}")'.format(self.filename)
 
-    def write(self, message: Message) -> int:
-        serialized = message.serialize(compress=False) + "\n".encode("utf-8")
+    def write(self, message: MessageBase) -> int:
+        if self.settings.content_only:
+            serialized = (json.dumps(message.content) + "\n").encode("utf-8")
+        else:
+            serialized = message.serialize(compress=False) + "\n".encode("utf-8")
         self.outFile.write(serialized)
         return len(serialized)
 
@@ -328,7 +342,7 @@ class CsvSource(SourceTap):
     def __repr__(self) -> str:
         return 'CsvSource("{}")'.format(self.filename)
 
-    def read(self) -> Iterator[Message]:
+    def read(self) -> Iterator[MessageBase]:
         for row in self.reader:
             yield Message(content=row)
 
@@ -371,7 +385,7 @@ class CsvDestination(DestinationTap):
     def __repr__(self) -> str:
         return 'CsvDestination("{}")'.format(self.filename)
 
-    def write(self, message: Message) -> int:
+    def write(self, message: MessageBase) -> int:
         if self.writer is None:
             self.writer = csv.DictWriter(
                 self.outFile,
